@@ -1,19 +1,19 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsdelf3.1"
+#define HOST_OS "freebsdelf3.3"
 #define HOST_OS_NAME "freebsdelf3"
-#define HOST_OS_VERSION "3.1"
+#define HOST_OS_VERSION "3.3"
 #define HOST_ARCH "i386"
 #define HOST_NAME "ape.mcl.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Sat Sep 18 17:52:09 EDT 1999"
+#define CONFIG_DATE "Mon Apr  3 19:35:29 EDT 2000"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.2s2"
+#define VERSION "6.0.4s4"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.2s2"
+#define VERSION "6.0.4s4"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "3.1"
+#define HOST_HEADER_VERSION "3.3"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_ALLOCA 1
@@ -25,6 +25,7 @@
 #define HAVE_BZERO 1
 #define HAVE_CLNT_CREATE 1
 #define HAVE_CLNT_SPCREATEERROR 1
+#define HAVE_CLOCK_GETTIME 1
 #define HAVE_FLOCK 1
 #define HAVE_GET_MYADDRESS 1
 #define HAVE_GETCWD 1
@@ -64,6 +65,7 @@
 #define HAVE_UNAME 1
 #define HAVE_UNMOUNT 1
 #define HAVE_VFORK 1
+#define HAVE_VSNPRINTF 1
 #define HAVE_WAIT3 1
 #define HAVE_WAITPID 1
 #define HAVE_CLNT_SPERRNO 1
@@ -186,7 +188,6 @@
 #define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
 #define TIME_WITH_SYS_TIME 1
-#define HAVE_ST_RDEV 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_freebsd3.h"
 #define HAVE_STRUCT_NFS_ARGS 1
 #define nfs_args_t struct nfs_args
@@ -203,7 +204,9 @@
 #define AUTH_CREATE_GIDLIST_TYPE gid_t
 #define SVC_IN_ARG_TYPE caddr_t
 #define cdfs_args_t struct iso_args
+#define mfs_args_t struct mfs_args
 #define pcfs_args_t struct msdosfs_args
+#define ufs_args_t struct ufs_args
 #define XDRPROC_T_TYPE xdrproc_t
 #define voidp void *
 #define HAVE_EXTERN_SYS_ERRLIST 1
@@ -228,8 +231,10 @@
 #define HAVE_EXTERN_UALARM 1
 #define HAVE_EXTERN_USLEEP 1
 #define HAVE_EXTERN_WAIT3 1
+#define HAVE_EXTERN_VSNPRINTF 1
 #define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
 #define HAVE_LONG_FILE_NAMES 1
+#define HAVE_UNISTD_H 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
 #define HAVE_FIELD_CDFS_ARGS_T_FLAGS 1
 #define HAVE_FIELD_CDFS_ARGS_T_FSPEC 1
@@ -238,6 +243,7 @@
 #define HAVE_FIELD_PCFS_ARGS_T_GID 1
 #define HAVE_FIELD_PCFS_ARGS_T_MASK 1
 #define HAVE_FIELD_PCFS_ARGS_T_UID 1
+#define HAVE_FIELD_UFS_ARGS_T_FSPEC 1
 #define HAVE_FIELD_STRUCT_STATFS_F_FSTYPENAME 1
 #define HAVE_FIELD_NFS_ARGS_T_ACDIRMIN 1
 #define HAVE_FIELD_NFS_ARGS_T_ACREGMIN 1
@@ -259,18 +265,18 @@
 #define HAVE_FS_PCFS 1
 #define HAVE_FS_UFS 1
 #define HAVE_FS_UNIONFS 1
-#define HAVE_AM_FS_AUTO 1
-#define HAVE_AM_FS_DIRECT 1
-#define HAVE_AM_FS_TOPLVL 1
-#define HAVE_AM_FS_ERROR 1
-#define HAVE_AM_FS_INHERIT 1
-#define HAVE_AM_FS_PROGRAM 1
-#define HAVE_AM_FS_LINK 1
-#define HAVE_AM_FS_LINKX 1
-#define HAVE_AM_FS_HOST 1
-#define HAVE_AM_FS_NFSX 1
-#define HAVE_AM_FS_NFSL 1
-#define HAVE_AM_FS_UNION 1
+#define HAVE_AMU_FS_AUTO 1
+#define HAVE_AMU_FS_DIRECT 1
+#define HAVE_AMU_FS_TOPLVL 1
+#define HAVE_AMU_FS_ERROR 1
+#define HAVE_AMU_FS_INHERIT 1
+#define HAVE_AMU_FS_PROGRAM 1
+#define HAVE_AMU_FS_LINK 1
+#define HAVE_AMU_FS_LINKX 1
+#define HAVE_AMU_FS_HOST 1
+#define HAVE_AMU_FS_NFSX 1
+#define HAVE_AMU_FS_NFSL 1
+#define HAVE_AMU_FS_UNION 1
 #define MOUNT_TYPE_NFS "nfs"
 #define MOUNT_TYPE_NFS3 MOUNT_NFS3
 #define MOUNT_TYPE_UFS "ufs"
